freeze;

/////////////////////////////////////////////////////////////////////////
// growl.m
/////////////////////////////////////////////////////////////////////////
// $Revision: 34307 $
// $Date: 2011-07-09 15:51:17 +0100 (Sat, 09 Jul 2011) $
// $LastChangedBy: kasprzyk $
/////////////////////////////////////////////////////////////////////////
// Author: Alexander Kasprzyk
/////////////////////////////////////////////////////////////////////////
// Allows logging via the Growl notification system.
/////////////////////////////////////////////////////////////////////////

import "logger.m": set_logger, set_logger_store_value, get_logger_store_value, get_hostname;

/////////////////////////////////////////////////////////////////////////
// Local functions
/////////////////////////////////////////////////////////////////////////

// Sends the given message to Growl.
procedure growl_logger_handler(message,level)
    bool,growl:=IsIntrinsic("Growl");
    if bool then
        bool,address:=get_logger_store_value("growl_address");
        assert bool;
        bool,password:=get_logger_store_value("growl_password");
        assert bool;
        bool,title:=get_logger_store_value("growl_title");
        assert bool;
        growl(title,message : address:=address, password:=password);
    end if;
end procedure;

/////////////////////////////////////////////////////////////////////////
// Intrinsics
/////////////////////////////////////////////////////////////////////////

intrinsic SetLoggerToGrowl(: address:=false, password:=false)
{Sets log messages to be sent to the Growl notification system, and enables logging.}
    // Sanity checks
    require not InternalIsPC(): "Operation not supported on Windows";
    if not address cmpeq false then
        require Type(address) eq MonStgElt: "'address' must be a string";
    end if;
    if not password cmpeq false then
        require Type(password) eq MonStgElt: "'password' must be a string";
    end if;
    bool:=IsIntrinsic("Growl");
    require bool: "Growl support is not enabled";
    // Create the title
    title:="Magma";
    if not address cmpeq false then
        hostname:=get_hostname();
        if #hostname gt 0 then
            title cat:= " on " cat hostname;
        end if;
    end if;
    // Set the logger
    set_logger_store_value("growl_address",address);
    set_logger_store_value("growl_password",password);
    set_logger_store_value("growl_title",title);
    set_logger(growl_logger_handler,"%s");
end intrinsic;
