freeze;

/////////////////////////////////////////////////////////////////////////
// pipes.m
/////////////////////////////////////////////////////////////////////////
// $Revision: 37568 $
// $Date: 2012-02-27 19:34:18 +0000 (Mon, 27 Feb 2012) $
// $LastChangedBy: kasprzyk $
/////////////////////////////////////////////////////////////////////////
// Author: Alexander Kasprzyk
/////////////////////////////////////////////////////////////////////////
// A collection of useful command-line interfaces.
/////////////////////////////////////////////////////////////////////////

/////////////////////////////////////////////////////////////////////////
// Functions
/////////////////////////////////////////////////////////////////////////

// Escapes the characters ", `, \, and $ in the given string
function escape_string( str )
    str:=SubstituteString(str,"\\","\\\\");
    str:=SubstituteString(str,"\"","\\\"");
    str:=SubstituteString(str,"`","\\\`");
    str:=SubstituteString(str,"$","\\\$");
    return str;
end function;

// Executes the given command with Pipe. Returns true followed by the result
// on success, false otherwise.
function pipe_command( C )
    if InternalIsPC() then return false,_; end if;
    try
        res:=Pipe(C cat " 2>&1 || echo \"_123FAILED\"","");
        res:=Trim(res);
    catch e;
        res:="_123FAILED";
    end try;
    if Index(res,"_123FAILED") ne 0 then
        return false,_;
    else
        return true,res;
    end if;
end function;

// Quotes the given path. Normally this will simply escape any quotes in the
// path and encase it with quotation marks. However, if the initial character is
// a tilde then it tries to get it correct.
function quote_path( path )
    path:=escape_string(path);
    if #path gt 0 and path[1] eq "~" then
        idx:=Index(path,"/");
        if idx eq 0 then idx:=#path; end if;
        initial:=path[1..idx];
        final:=path[idx + 1..#path];
        initial:=SubstituteString(initial," ","\\\ ");
        initial:=SubstituteString(initial,";","\\\;");
        initial:=SubstituteString(initial,"&","\\\&");
        initial:=SubstituteString(initial,"|","\\\|");
        if #final gt 0 then
            return initial cat "\"" cat final cat "\"";
        else
            return initial;
        end if;
    else
        return "\"" cat path cat "\"";
    end if;
end function;
